@@ -28,10 +28,12 @@ impl<'a> Default for OSConfig<'a> {
             format: "[$symbol]($style)",
             style: "bold white",
             symbols: indexmap! {
+                Type::Alpaquita => "🔔 ",
                 Type::Alpine => "🏔️ ",
                 Type::Amazon => "🙂 ",
                 Type::Android => "🤖 ",
                 Type::Arch => "🎗️ ",
+                Type::Artix => "🎗️ ",
                 Type::CentOS => "💠 ",
                 Type::Debian => "🌀 ",
                 Type::DragonFly => "🐉 ",
@@ -44,6 +46,7 @@ impl<'a> Default for OSConfig<'a> {
                 Type::HardenedBSD => "🛡️ ",
                 Type::Illumos => "🐦 ",
                 Type::Linux => "🐧 ",
+                Type::Mabox => "📦 ",
                 Type::Macos => "🍎 ",
                 Type::Manjaro => "🥭 ",
                 Type::Mariner => "🌊 ",
